# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#

from .core import ChecksumMixin, _ord
from .typedef import ULInt32


class Checksum32(ULInt32, ChecksumMixin):
    """
    Example implementation for ChecksumMixin
    """
    _original_type = ULInt32

    def __init__(self, strict=False, automatic_calculation=True):
        self._strict = strict
        self.set_automatic_calculation(automatic_calculation)
        super(Checksum32, self).__init__()

    def _calculate_checksum(self, data):
        checksum = 0
        for byte in data:
            checksum += _ord(byte)

        return checksum

    def encode(self, full_data=b"", context_data=b""):
        return ChecksumMixin.encode(self, full_data, context_data)

    def decode(self, data, full_data=b"", context_data=b""):
        return ChecksumMixin.decode(self, data, full_data, context_data)

    def _fuzzing_value_iterator(self):
        """
        A generator for all fuzzing values set.
        This sets automatic calculation and strict temporarly to False 
        if fuzzing values are set and restores the original values after the
        fuzzing iterator ends.

        Returns:
            self: if no fuzzing values are set

        Yields:
            fuzzing values
        """
        # store old values
        self._tmp_strict = self._strict
        self._tmp_automatic_calculation = self._automatic_calculation

        if self._fuzzing_values is not None:
            # disable strict and automatic_calculation
            self._strict = False
            self._automatic_calculation = False

        for value in super(self._original_type, self)._fuzzing_value_iterator():
            yield value

        # restore values
        self._strict = self._tmp_strict
        self._automatic_calculation = self._tmp_automatic_calculation
