# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from oser.core import RepeatUntil as _RepeatUntil


class RepeatUntil(_RepeatUntil):
    """
    ``RepeatUntil`` builds an array serializer with a variable length that is determined dynamically on decoding.
    """

    def __init__(self, length, stop_condition, prototype, stop_on_exception=False, args=None, kwargs=None, values=None):
        """
        Args:
            length (integer): states the initial length
            stop_condition (callable): the stop condition called with ``context``, ``data``
                (the next bytes to be parsed), ``full_data`` (all data) and ``context_data``
                the data within the current hierarchy. If ``stop_condition`` returns ``True`` decoding stops.
            prototype (an OSER class): a class that is the prototype for `values`
            stop_on_exception (bool): if set to ``True`` a ``DecodeException`` is handled as a stop condition.
            args=None (tuple): a tuple of positional arguments that are passed to `prototype` when it is instantiated
                when array size is extended.
                Note: don't forget a leading comma when passing one value ``(1,)`` (``(1)`` is an integer!).
            kwargs=None (dict): a dictionary of named arguments that are passed to `prototype` when it is instantiated
                when array size is extended.
            values=None (list containing instances of ``prototype``): the initial array values. Can be left empty.
                If empty the array is automatically resized with instances of ``prototype(*args, **kwargs)``.
        """
        super(RepeatUntil, self).__init__(length=length, stop_condition=stop_condition, prototype=prototype, stop_on_exception=stop_on_exception, args=args, kwargs=kwargs, values=values)

    def decode(self, data, full_data=b'', context_data=b''):
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data (bytes): the data buffer that is decoded.
            full_data (bytes): the binary data string until the part to be decoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context. The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(RepeatUntil, self).decode(data=data, full_data=full_data, context_data=context_data)

    def encode(self, full_data=b'', context_data=b''):
        """
        Return the encoded binary string.

        Args:
            full_data (bytes): the binary data string until the part to be
                encoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            bytes: the encoded binary string.
        """
        return super(RepeatUntil, self).encode(full_data=full_data, context_data=context_data)

    def from_dict(self, data):
        """
        Fill self with data.

        Args:
            data (dict): data to be used to fill the calling instance.
        """
        return super(RepeatUntil, self).from_dict(data=data)

    def fuzzing_iterator(self, copy=False):
        """
        The fuzzing iterator iterates over all combinations
        of set fuzzing values (:func:`oser.ByteType.set_fuzzing_values`).
        If no fuzzing values are set the current struct is yielded.

        Args:
            copy=False (bool): if set to ``True`` the generated
                fuzzing values are deep copies of the original.
                Creating these deep copies is slow. If set to ``False`` the
                original struct is retruned and the generated value must be
                used immediately since the next generated overwrites the values
                on the same value.

        Yields:
            the fuzzing combinations.
        """
        return super(RepeatUntil, self).fuzzing_iterator(copy=copy)

    def get(self):
        """
        Return the value.
        """
        return super(RepeatUntil, self).get()

    def introspect(self, stop_at=None):
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None (object): stop introspection at ``stop_at``.
        """
        return super(RepeatUntil, self).introspect(stop_at=stop_at)

    def root(self):
        """
        return root element
        """
        return super(RepeatUntil, self).root()

    def set_length(self, length):
        """
        Set the length.

        Args:
            length (int): the new length
        """
        return super(RepeatUntil, self).set_length(length=length)

    def get_size(self):
        """
        Return the current size in bytes.
        """
        return super(RepeatUntil, self).get_size()

    get_byte_size = get_size

    def to_dict(self):
        """
        Return self as a dict()
        """
        return super(RepeatUntil, self).to_dict()

    def up(self):
        """
        return parent element
        """
        return super(RepeatUntil, self).up()

