# -*- coding: utf-8 -*-
#
# Copyright (c) 2021, HILSTER GmbH, Germany - https://hilster.io
# All rights reserved.
#
# This file was generated by wrappergenerator.py
#

from oser.core import Switch as _Switch


class Switch(_Switch):
    """
    ``Switch`` builds a conditional serializer.
    """

    def __init__(self, condition, values, default=None):
        """
        Args:
            condition: the key which selects the desired values. Can be a callable (e.g. lambda) or a scalar.
            values: a dictionary that holds key-value pairs. The key is selected by the value (or return value)
                of `condition` and the value is used as the actual serializer.
            default=None: if not `None` this value is used as a serializer if `condition` is not found in `values`
        """
        super(Switch, self).__init__(condition=condition, values=values, default=default)

    def get_byte_size(self):
        """
        Return the current size in bytes.
        """
        return super(Switch, self).get_byte_size()

    def decode(self, data, full_data=b'', context_data=b''):
        """
        Decode a binary string and return the number
        of bytes that were decoded.

        Args:
            data (bytes): the data buffer that is decoded.
            full_data (bytes): the binary data string until the part to be decoded.
                The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            int: the number of bytes that were decoded.
        """
        return super(Switch, self).decode(data=data, full_data=full_data, context_data=context_data)

    def delete_value(self, key):
        """
        Delete the value identified by ``key``.

        Args:
            key: the key for the value to be deleted.
        """
        return super(Switch, self).delete_value(key=key)

    def encode(self, full_data=b'', context_data=b''):
        """
        Return the encoded binary string.

        Args:
            full_data (bytes): the binary data string until the part to be
                encoded. The user normally does not need to supply this.
            context_data (bytes): the binary data of the current context.
                The user normally does not need to supply this.

        Returns:
            bytes: the encoded binary string.
        """
        return super(Switch, self).encode(full_data=full_data, context_data=context_data)

    def from_dict(self, data):
        """
        Fill self with data.

        Args:
            data (dict): data to be used to fill the calling instance.
        """
        return super(Switch, self).from_dict(data=data)

    def fuzzing_iterator(self, copy=False):
        """
        The fuzzing iterator iterates over all combinations
        of set fuzzing values (:func:`oser.ByteType.set_fuzzing_values`).
        If no fuzzing values are set the current struct is yielded.

        Args:
            copy=False (bool): if set to ``True`` the generated
                fuzzing values are deep copies of the original.
                Creating these deep copies is slow. If set to ``False`` the
                original struct is retruned and the generated value must be
                used immediately since the next generated overwrites the values
                on the same value.

        Yields:
            the fuzzing combinations.
        """
        return super(Switch, self).fuzzing_iterator(copy=copy)

    def get(self):
        """
        Return the current value.
        """
        return super(Switch, self).get()

    def get_current(self):
        """
        Return the currently selected object.
        """
        return super(Switch, self).get_current()

    def get_items(self):
        """
        Return the items of the values (like in a ``dict``).
        """
        return super(Switch, self).get_items()

    def get_keys(self):
        """
        Return the keys of the values (like in a ``dict``).
        """
        return super(Switch, self).get_keys()

    def get_value(self, key):
        """
        Get the value for ``key``.

        Args:
            key: the key for the condition.

        Returns:
            the value for the ``condition`` ``key``.
        """
        return super(Switch, self).get_value(key=key)

    def get_values(self):
        """
        Return the values of the ``values`` (like in a ``dict``).
        """
        return super(Switch, self).get_values()

    def introspect(self, stop_at=None):
        """
        Return the introspection representation of the object
        as a string.

        Args:
            stop_at=None (object): stop introspection at ``stop_at``.
        """
        return super(Switch, self).introspect(stop_at=stop_at)

    def root(self):
        """
        return root element
        """
        return super(Switch, self).root()

    def set(self, value):
        """
        Set the current value.

        Args:
            value: the new value.
        """
        return super(Switch, self).set(value=value)

    def set_value(self, key, value):
        """
        Get the value for ``key``.

        Args:
            key: the key for the condition.
            value: the value for the ``key``.
        """
        return super(Switch, self).set_value(key=key, value=value)

    def get_size(self):
        """
        Return the current size in bytes or bits according to the context.
        """
        return super(Switch, self).get_size()

    def to_dict(self):
        """
        Return self as a dict()
        """
        return super(Switch, self).to_dict()

    def up(self):
        """
        return parent element
        """
        return super(Switch, self).up()

    def update_values(self, values):
        """
        Update the values. Overwrites or adds new keys and values.

        Args:
            values (dict): the dict with the new values.
        """
        return super(Switch, self).update_values(values=values)

